@@ -44,6 +44,7 @@ class WebDriver(webdriver.Remote):
         # add new method to the `find_by_*` pantheon
         By.IOS_UIAUTOMATION = MobileBy.IOS_UIAUTOMATION
         By.IOS_PREDICATE = MobileBy.IOS_PREDICATE
+        By.IOS_CLASS_CHAIN = MobileBy.IOS_CLASS_CHAIN
         By.ANDROID_UIAUTOMATOR = MobileBy.ANDROID_UIAUTOMATOR
         By.ACCESSIBILITY_ID = MobileBy.ACCESSIBILITY_ID
 
@@ -121,6 +122,28 @@ class WebDriver(webdriver.Remote):
         """
         return self.find_elements(by=By.IOS_PREDICATE, value=predicate_string)
 
+    def find_element_by_ios_class_chain(self, class_chain_string):
+        """Find an element by ios class chain string.
+
+        :Args:
+         - class_chain_string - The class chain string
+
+        :Usage:
+            driver.find_element_by_ios_class_chain('XCUIElementTypeWindow/XCUIElementTypeButton[3]')
+        """
+        return self.find_element(by=By.IOS_CLASS_CHAIN, value=class_chain_string)
+
+    def find_elements_by_ios_class_chain(self, class_chain_string):
+        """Finds elements by ios class chain string.
+
+        :Args:
+         - class_chain_string - The class chain string
+
+        :Usage:
+            driver.find_elements_by_ios_class_chain('XCUIElementTypeWindow[2]/XCUIElementTypeAny[-2]')
+        """
+        return self.find_elements(by=By.IOS_CLASS_CHAIN, value=class_chain_string)
+
     def find_element_by_android_uiautomator(self, uia_string):
         """Finds element by uiautomator in Android.
 
@@ -423,10 +446,16 @@ class WebDriver(webdriver.Remote):
 
     @property
     def current_activity(self):
-        """Retrieves the current activity on the device.
+        """Retrieves the current activity running on the device.
         """
         return self.execute(Command.GET_CURRENT_ACTIVITY)['value']
 
+    @property
+    def current_package(self):
+        """Retrieves the current package running on the device.
+        """
+        return self.execute(Command.GET_CURRENT_PACKAGE)['value']
+
     def wait_activity(self, activity, timeout, interval=1):
         """Wait for an activity: block until target activity presents
         or time out.
@@ -630,7 +659,7 @@ class WebDriver(webdriver.Remote):
         return self
 
     def touch_id(self, match):
-        """Do a fingerprint scan
+        """Simulate touchId on iOS Simulator
         """
         data = {
             'match': match
@@ -638,6 +667,12 @@ class WebDriver(webdriver.Remote):
         self.execute(Command.TOUCH_ID, data)
         return self
 
+    def toggle_touch_id_enrollment(self):
+        """Toggle enroll touchId on iOS Simulator
+        """
+        self.execute(Command.TOGGLE_TOUCH_ID_ENROLLMENT)
+        return self
+
     def open_notifications(self):
         """Open notification shade in Android (API Level 18 and above)
         """
@@ -762,7 +797,7 @@ class WebDriver(webdriver.Remote):
 
     @property
     def device_time(self):
-        """Returns the date and time fomr the device
+        """Returns the date and time from the device
         """
         return self.execute(Command.GET_DEVICE_TIME, {})['value']
 
@@ -788,6 +823,8 @@ class WebDriver(webdriver.Remote):
             ('POST', '/session/$sessionId/appium/device/long_press_keycode')
         self.command_executor._commands[Command.GET_CURRENT_ACTIVITY] = \
             ('GET', '/session/$sessionId/appium/device/current_activity')
+        self.command_executor._commands[Command.GET_CURRENT_PACKAGE] = \
+            ('GET', '/session/$sessionId/appium/device/current_package')
         self.command_executor._commands[Command.SET_IMMEDIATE_VALUE] = \
             ('POST', '/session/$sessionId/appium/element/$id/value')
         self.command_executor._commands[Command.PULL_FILE] = \
@@ -818,6 +855,8 @@ class WebDriver(webdriver.Remote):
             ('POST', '/session/$sessionId/appium/device/shake')
         self.command_executor._commands[Command.TOUCH_ID] = \
             ('POST', '/session/$sessionId/appium/simulator/touch_id')
+        self.command_executor._commands[Command.TOGGLE_TOUCH_ID_ENROLLMENT] = \
+            ('POST', '/session/$sessionId/appium/simulator/toggle_touch_id_enrollment')
         self.command_executor._commands[Command.RESET] = \
             ('POST', '/session/$sessionId/appium/app/reset')
         self.command_executor._commands[Command.HIDE_KEYBOARD] = \
